@@ -1,7 +1,9 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
+ * MIT license
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -10,6 +12,22 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
+ * Apache license, Version 2.0
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 //! `FEEL` days and time durations.
@@ -81,7 +99,7 @@ impl FeelDaysAndTimeDuration {
   }
   /// Returns absolute value of the duration.
   pub fn abs(&self) -> Self {
-    Self(-self.0)
+    Self(self.0.abs())
   }
 }
 
@@ -345,6 +363,8 @@ mod tests {
     equals_str("-PT59M59.999999999S", true, 3_599, 999_999_999);
     equals_str("PT1H", false, 3_600, 0);
     equals_str("-PT1H", true, 3_600, 0);
+    equals_str("PT1H10S", false, 3_610, 0);
+    equals_str("-PT1H10S", true, 3_610, 0);
     equals_str("PT1H0.3459S", false, 3_600, 345_900_000);
     equals_str("-PT1H0.3459S", true, 3_600, 345_900_000);
     equals_str("PT1H59.11S", false, 3_659, 110_000_000);
@@ -595,4 +615,16 @@ mod tests {
     assert_eq!(36, duration.get_seconds());
     assert_eq!(-278_316, duration.as_seconds());
   }
+
+  #[test]
+  fn test_abs_should_pass() {
+    let duration = FeelDaysAndTimeDuration::try_from("PT12S").unwrap();
+    assert_eq!("PT12S", duration.abs().to_string());
+    let duration = FeelDaysAndTimeDuration::try_from("-PT12S").unwrap();
+    assert_eq!("PT12S", duration.abs().to_string());
+    let duration = FeelDaysAndTimeDuration::try_from("P3DT5H18M36S").unwrap();
+    assert_eq!("P3DT5H18M36S", duration.abs().to_string());
+    let duration = FeelDaysAndTimeDuration::try_from("-P3DT5H18M36S").unwrap();
+    assert_eq!("P3DT5H18M36S", duration.abs().to_string());
+  }
 }
