@@ -1,7 +1,9 @@
 /*
  * DMNTK - Decision Model and Notation Toolkit
  *
- * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
+ * MIT license
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
  *
  * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
@@ -10,11 +12,28 @@
  * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
+ *
+ * Apache license, Version 2.0
+ *
+ * Copyright (c) 2018-2021 Dariusz Depta Engos Software
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 //! Date and time utilities.
 
 use crate::temporal::date::{is_valid_date, FeelDate};
+use crate::temporal::errors::*;
 use crate::temporal::ym_duration::FeelYearsAndMonthsDuration;
 use crate::temporal::zone::FeelZone;
 use chrono::{DateTime, Datelike, FixedOffset, Local, LocalResult, NaiveDate, NaiveDateTime, NaiveTime, TimeZone, Utc};
@@ -27,6 +46,7 @@ use std::ops::Sub;
 pub mod date;
 pub mod date_time;
 pub mod dt_duration;
+mod errors;
 pub mod time;
 pub mod ym_duration;
 pub mod zone;
@@ -40,7 +60,7 @@ const TIME_PATTERN: &str = r#"(?P<hours>[0-9]{2}):(?P<minutes>[0-9]{2}):(?P<seco
 /// Regular expression patterns for parsing time zones.
 const ZULU_PATTERN: &str = r#"(?P<zulu>[zZ])"#;
 const ZONE_PATTERN: &str = r#"@(?P<zone>[a-zA-Z_/]+)"#;
-const OFFSET_PATTERN: &str = r#"(?P<offSign>[+-])(?P<offHour>[0-9]{2}):(?P<offMinute>[0-9]{2})"#;
+const OFFSET_PATTERN: &str = r#"(?P<offSign>[+-])(?P<offHours>[0-9]{2}):(?P<offMinutes>[0-9]{2})(:(?P<offSeconds>[0-9]{2}))?"#;
 
 /// Number of nanoseconds in a second.
 const NANOS_IN_SECOND: u64 = 1_000_000_000;
@@ -100,7 +120,7 @@ impl TryFrom<FeelTime> for DateTime<FixedOffset> {
 }
 
 impl FeelTime {
-  pub fn new_hmso_opt(hour: u8, minute: u8, second: u8, nano: u64, offset: i64) -> Option<Self> {
+  pub fn new_hmso_opt(hour: u8, minute: u8, second: u8, nano: u64, offset: i32) -> Option<Self> {
     if is_valid_time(hour, minute, second) {
       Some(Self(hour, minute, second, nano, FeelZone::new(offset)))
     } else {
@@ -117,13 +137,18 @@ impl FeelTime {
   }
 
   /// Creates UTC time from specified time values.
-  pub fn utc(hour: u8, minute: u8, second: u8, nanosecond: u64) -> Self {
-    Self(hour, minute, second, nanosecond, FeelZone::Utc)
+  pub fn utc(hour: u8, minute: u8, second: u8, nanos: u64) -> Self {
+    Self(hour, minute, second, nanos, FeelZone::Utc)
   }
 
   /// Creates local time from specified time values.
-  pub fn local(hour: u8, minute: u8, second: u8, nanosecond: u64) -> Self {
-    Self(hour, minute, second, nanosecond, FeelZone::Local)
+  pub fn local(hour: u8, minute: u8, second: u8, nanos: u64) -> Self {
+    Self(hour, minute, second, nanos, FeelZone::Local)
+  }
+
+  /// Creates a time from specified time and offset values.
+  pub fn offset(hour: u8, minute: u8, second: u8, nanos: u64, offset: i32) -> Self {
+    Self(hour, minute, second, nanos, FeelZone::Offset(offset))
   }
 
   /// Compares this time value with other time value and returns [Some] ([true])
@@ -247,7 +272,7 @@ impl TryFrom<&str> for FeelDateTime {
         }
       }
     }
-    Err(crate::temporal::date_time::errors::invalid_date_time_literal(value.to_string()))
+    Err(err_invalid_date_time_literal(value))
   }
 }
 
@@ -306,6 +331,11 @@ impl FeelDateTime {
     Self(FeelDate::new(year, month, day), FeelTime::local(hour, min, sec, nanos))
   }
 
+  /// Creates  date and time from specified date, time and offset values.
+  pub fn offset(date: (i32, u8, u8), time: (u8, u8, u8, u64), offset: i32) -> Self {
+    Self(FeelDate::new(date.0, date.1, date.2), FeelTime::offset(time.0, time.1, time.2, time.3, offset))
+  }
+
   /// Returns the `Date` part from date and time value.
   pub fn date(&self) -> FeelDate {
     self.0.clone()
